Enum fractal_dto::v1::oauth::ScopeDTO
[−]
[src]
pub enum ScopeDTO {
Admin,
User(u64),
Public,
}Enum that represents a scope.
Variants
AdminAdministration scope
This scope is used for administration purposes, and will not be enabled for public development accounts.
User(u64)User scope
This scope will provide access to user functionality, such as creating transactions and editing user information. It contains the user ID for which the token is valid.
PublicPublic scope
This scope is the public scope. Every client will have access to everything provided in the public scope.